#
# spec file for package purple-plugin-pack
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2007 Ivan N. Zlatev <contact@i-nz.net>
# Copyright (c) 2009 Lukas Krejza <gryffus@hkfree.org>
# Copyright (c) 2011 Christoph Miebach <christoph.miebach@web.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           purple-plugin-pack
Version:        2.8.0
Release:        1.6
Summary:        Compilation of plugins for libpurple and Pidgin
# FIXME: On new upstream version, check if GPLv3+ plugins are still under the same licence (add COPYING.GPL3 to the extras subpackage if present upstream).
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Networking/Instant Messenger
URL:            https://keep.imfreedom.org/pidgin/purple-plugin-pack/
Source:         https://downloads.sourceforge.net/pidgin/purple%20plugin%20pack/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(finch)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gnt)
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.10.0
BuildRequires:  pkgconfig(gtkspell-2.0) >= 2.0.2
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pidgin)
BuildRequires:  pkgconfig(purple)

%description
The Purple Plugin Pack is a compilation of plugins for the libpurple
family of IM clients.

%package -n libpurple-plugin-pack
Summary:        Compilation of plugins for libpurple
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Instant Messenger
Recommends:     libpurple-plugin-pack-lang
Enhances:       libpurple
# purple-plugin_pack was last used in openSUSE 12.1.
Provides:       purple-plugin_pack = %{version}
Obsoletes:      purple-plugin_pack < %{version}
# purple-plugin-pack-lang was last used in openSUSE Leap 42.2.
Obsoletes:      %{name}-lang < %{version}-%{release}

%description -n libpurple-plugin-pack
The Purple Plugin Pack is a compilation of plugins for the
libpurple family of IM clients.

To avoid licence issues between GPLv3+ plugins and other plugins
that could be incompatible with GPLv3+, the GPLv3+ plugins are
split into the libpurple-plugin-pack-extras package.

%lang_package -n libpurple-plugin-pack

%package -n libpurple-plugin-pack-extras
Summary:        Compilation of plugins for libpurple -- GPLv3+ Plugins
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Instant Messenger
Requires:       libpurple-plugin-pack = %{version}
Enhances:       libpurple-plugin-pack

%description -n libpurple-plugin-pack-extras
The Purple Plugin Pack is a compilation of plugins for the
libpurple family of IM clients.

This package contains GPLv3+ plugins. Their licence might cause
incompatibilities with other plugins.

%package -n pidgin-plugin-pack
Summary:        Compilation of plugins for Pidgin
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Instant Messenger
Requires:       libpurple-plugin-pack = %{version}
%requires_ge    pidgin
Supplements:    packageand(pidgin:libpurple-plugin-pack)
# pidgin-plugin_pack was last used in openSUSE 12.1.
Provides:       pidgin-plugin_pack = %{version}
Obsoletes:      pidgin-plugin_pack < %{version}

%description -n pidgin-plugin-pack
The Purple Plugin Pack is a compilation of plugins for the
libpurple family of IM clients.

This package provides the Pidgin plugins from the Purple Plugin Pack.

To avoid licence issues between GPLv+ plugins and other plugins
that could be incompatible with GPLv3+, the GPLv3+ plugins are split
into the pidgin-plugin-pack-extras package.

%package -n pidgin-plugin-pack-extras
Summary:        Compilation of plugins for Pidgin -- GPLv3+ Plugins
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Instant Messenger
Requires:       libpurple-plugin-pack-extras = %{version}
Requires:       pidgin-plugin-pack = %{version}
Enhances:       pidgin-plugin-pack
Supplements:    packageand(pidgin:libpurple-plugin-pack-extras)

%description -n pidgin-plugin-pack-extras
The Purple Plugin Pack is a compilation of plugins for the
libpurple family of IM clients.

This package provides the Pidgin plugins from the Purple Plugin Pack.

This package contains GPLv3+ plugins. Their licence might cause
incompatibilities with other plugins.

%prep
%autosetup -p1

%build
meson build -Dprefix=/usr
ninja -C build

%install
DESTDIR=%{buildroot} meson install -C build
%find_lang plugin_pack

%files -n libpurple-plugin-pack
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS ChangeLog README.md
# Explicitly list plugins to notice when any is missing and to ease split with extras.
%{_libdir}/purple-2/autoreply.so
%{_libdir}/purple-2/bash.so
%{_libdir}/purple-2/capsnot.so
%{_libdir}/purple-2/colorize.so
%{_libdir}/purple-2/dewysiwygification.so
%{_libdir}/purple-2/dice.so
%{_libdir}/purple-2/eight_ball.so
%{_libdir}/purple-2/flip.so
%{_libdir}/purple-2/google.so
%{_libdir}/purple-2/groupmsg.so
%{_libdir}/purple-2/highlight.so
%{_libdir}/purple-2/ignore.so
%{_libdir}/purple-2/irchelper.so
%{_libdir}/purple-2/irc-more.so
%{_libdir}/purple-2/listhandler.so
%{_libdir}/purple-2/oldlogger.so
%{_libdir}/purple-2/showoffline.so
%{_libdir}/purple-2/simfix.so
%{_libdir}/purple-2/slashexec.so
%{_libdir}/purple-2/snpp.so
%{_libdir}/purple-2/splitter.so
%{_libdir}/purple-2/sslinfo.so
%{_libdir}/purple-2/translate.so
%{_libdir}/purple-2/xmppprio.so
%{_datadir}/metainfo/purple-plugin-pack.metainfo.xml

%files -n libpurple-plugin-pack-lang -f plugin_pack.lang

%files -n libpurple-plugin-pack-extras
%doc AUTHORS ChangeLog README.md
%{_libdir}/purple-2/ning.so
%{_libdir}/purple-2/okcupid.so
%{_libdir}/purple-2/omegle.so

%files -n pidgin-plugin-pack
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS ChangeLog README.md
# Explicitly list plugins to notice when any is missing and to ease split with extras.
%{_libdir}/pidgin/album.so
%{_libdir}/pidgin/blistops.so
%{_libdir}/pidgin/convbadger.so
%{_libdir}/pidgin/difftopic.so
%{_libdir}/pidgin/enhancedhist.so
%{_libdir}/pidgin/gRIM.so
%{_libdir}/pidgin/icon-override.so
%{_libdir}/pidgin/irssi.so
%{_libdir}/pidgin/lastseen.so
%{_libdir}/pidgin/listlog.so
%{_libdir}/pidgin/mystatusbox.so
%{_libdir}/pidgin/nicksaid.so
%{_libdir}/pidgin/plonkers.so
%{_libdir}/pidgin/schedule.so
%{_libdir}/pidgin/sepandtab.so
%{_libdir}/pidgin/switchspell.so
%{_libdir}/pidgin/timelog.so

%files -n pidgin-plugin-pack-extras
%doc AUTHORS ChangeLog README.md
%{_datadir}/pixmaps/pidgin/protocols/*/okcupid.png

%changelog
* Mon Oct 31 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.8.0:
  * Switched the build system from autotools to meson which also removed
    the need for plugin_pack.py.
  * Set the glib dependency to versions >= 2.32.0.
  * Set the gtk dependency to versions >= 2.10.0.
  * Removed the irssi happy new year easter egg.
  * Removed xmms-remote as XMMS 1.x has been dead for quite some time.
  * Removed the autoprofile plugin as it was incomplete and unlikely to be
    completed.
  * Removed the infopane plugin as it wasn't very useful.
  * Removed the talkfilters plugin as its dependencies are not typically
    packaged by distributions anymore.
  * Removed the Napster plugin as opennap hasn't been updated in 20 years.
  * Removed the xchat-chats plugin as it's kind of hacky and bundles a very
    old version of the xchat widget.
  * Removed the awaynotify plugin as it was incomplete and unlikely to be
    completed.
  * Removed the buddy icon tools plugin as it was incomplete and unlikely to be completed.
  * Removed the buddytime plugin as it was incomplete and unlikely to be
    completed.
  * Removed the chronic plugin as it was incomplete and unlikely to be
    completed.
  * Removed the stocker plugin as the AOL servers it talked to have long since
    been shutdown.
  * Removed the smartear plugin as it was incomplete and unlikely to be
    completed.
  * Removed the nomobility plugin as it was incomplete and unlikely to be
    completed.
  * Removed the msglen plugin as it was incomplete and unlikely to be completed.
  * Removed the ignorance plugin as it was incomplete and unlikely to be
    completed.
  * Removed the hideconv plugin as its functionality is in pidgin 2.3.0 and
    newer.
  * Removed the findip plugin as it never really worked in the first place.
  * Removed the stress plugin as it didn't build by default.
- Remove patches:
  * purple-plugin-pack-fix-autoprofile-crash.patch
  * purple-plugin_pack-fix-warning.patch
- Update BuildRequires.
- Update URL and Source location.
* Mon Mar 19 2018 sor.alexei@meowr.ru
- Add a missing build dependency: python2.
* Fri Dec 23 2016 sor.alexei@meowr.ru
- Replace purple-plugin_pack-autoprofile-crash.patch with
  purple-plugin-pack-fix-autoprofile-crash.patch, a very simple
  patch to do the job.
* Thu Jan 19 2012 vuntz@opensuse.org
- Add pkgconfig(json-glib-1.0) BuildRequires to build new Ning,
  OkCupid and Omegle protocol plugins.
- Create extras subpackages:
  + The main reason is to mitigate the risk of license
    incompatibilities between GPL-3.0+ plugins and other plugins
    that could be non-GPL-3.0-compatible.
  + Move the GPL-3.0+ plugins to extras subpackages.
  + Clearly document in summaries and descriptions why we have
    extras subpackages.
  + This should fix bnc#741195.
* Sat Dec  3 2011 christoph.miebach@web.de
- Version update to 2.7.0
  + Added German translation
  + Added capsnot plugin
  + Added icon-override plugin
  + Added translate plugin
  + Added Ning protocol plugin
  + Added OkCupid protocol plugin
  + Added Omegle protocol plugin
  + Fix a use-after-free in IRC Helper.
  + IRC Helper delays autojoins until after identifying with Purple
    2.7.0 or newer.
  + Support new Freenode IDENTIFY syntax in IRC Helper so users can
    log into services even when using an alternate or new nick.
  + IRC Helper now properly supports and suppresses new Freenode
    welcome and identified messages.
  + Updated website string to reflect project move from Trac to
    Redmine
  + Changed package name from purple-plugin_pack to
    purple-plugin-pack.
  + The Album plugin should no longer crash on non-buddies.
- Renamed source package from purple-plugin_pack to
  purple-plugin-pack, following upstream change. This also results
  in:
  + purple-plugin_pack Provides/Obsoletes in libpurple-plugin-pack
    (see below for why it's purple-plugin_pack
  + pidgin-plugin_pack Provides/Obsoletes in pidgin-plugin-pack.
- Drop purple-plugin_pack-de-l10n.patch.bz2 and
  purple-plugin_pack-fix-localedir.patch: fixed upstream.
- Remove call to autoreconf that was only needed for patches above.
- Properly package libpurple plugins in libpurple-plugin-pack
  instead of purple-plugin-pack.
* Thu Sep 29 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Mon Aug  1 2011 christoph.miebach@web.de
- Version update to 2.6.3
  + Add support for Spidernet to IRC Helper plugin.
  + IRC Helper now supports suppressing messages from the Freenode
    bot frigg.
  + IRC-More now builds when you pass --with-plugins=irc-more to
    configure.
  + IRC-More no longer tries to set umodes on connect if none are
    specified.
  + IRC-More now provides a channel autojoin list.  Autojoins
    happen with a 6-second delay to allow IRC Helper to do its job
    first.
- Added german translation not available at buildtime of 2.6.3
- Patch to find and use the translations
- Patch preventing crash in Autoprofile not run in english
- Patch fixing portability issue
* Fri Feb 13 2009 gryffus@hkfree.org
- Disabled xmmsremote plugin
* Wed Feb 11 2009 gryffus@hkfree.org
- Version upgrade to 2.5.1
- Added debuginfo and debugsource packages
- Fixes in .spec
* Mon Dec 29 2008 contact@i-nz.net
- Fixes for openSUSE 11.1
* Fri Aug 24 2007 michel.sylvan@gmail.com
- Add missing BRs on libxml2-devel and NetworkManager-devel
* Fri Aug 24 2007 michel.sylvan@gmail.com
- Update to 2.1.1, rename to purple-plugin_pack
- Move changelog to .changes file
* Sun May  6 2007 contact@i-nz.net
- new package
